import 'package:flutter/material.dart';

import 'package:momomotus/layout/board.dart';
import 'package:momomotus/layout/keyboard.dart';
import 'package:momomotus/provider/data.dart';
import 'package:momomotus/utils/game_utils.dart';

class Game {
  static Widget buildGameWidget(Data myProvider) {
    bool gameIsFinished = myProvider.isGameFinished();

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Expanded(
          child: Board.buildGameBoard(myProvider),
        ),
        const SizedBox(height: 2),
        SizedBox(
          height: 150,
          width: double.maxFinite,
          child: gameIsFinished
              ? Game.buildEndGameMessage(myProvider)
              : Keyboard.buildWidget(myProvider),
        ),
      ],
    );
  }

  static TextButton buildQuitGameButton(Data myProvider) {
    return TextButton(
      child: const Image(
        image: AssetImage('assets/icons/button_back.png'),
        fit: BoxFit.fill,
      ),
      onPressed: () => GameUtils.quitGame(myProvider),
    );
  }

  static Container buildEndGameMessage(Data myProvider) {
    String decorationImageAssetName = '';
    if (myProvider.gameWon) {
      decorationImageAssetName = 'assets/icons/game_win.png';
    } else {
      decorationImageAssetName = 'assets/icons/game_fail.png';
    }

    Widget decorationWidget = TextButton(
      child: Image(
        image: AssetImage(decorationImageAssetName),
        fit: BoxFit.fill,
      ),
      onPressed: () {},
    );

    return Container(
      margin: const EdgeInsets.all(2),
      padding: const EdgeInsets.all(2),
      child: Table(
        defaultColumnWidth: const IntrinsicColumnWidth(),
        children: [
          TableRow(
            children: [
              Column(
                children: [decorationWidget],
              ),
              Column(
                children: [buildQuitGameButton(myProvider)],
              ),
              Column(
                children: [decorationWidget],
              ),
            ],
          ),
        ],
      ),
    );
  }
}
